@@ -4,6 +4,9 @@ use strict;
 use warnings;
 use DynaLoader;
 
+# Make sure debugging with Data::Dumper is more easily comparable:
+$Data::Dumper::Sortkeys = 1;
+
 # different files, but same package
 # require them here to avoid dependencies
 use URPM::Build;
@@ -11,7 +14,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '5.22';
+our $VERSION = 'v5.225';
 
 URPM->bootstrap($VERSION);
 
@@ -290,7 +293,7 @@ URPM - Manipulate RPM files and headers
     });
 
     # loading and parsing a synthesis file
-    my $urpm = new URPM;
+    my $urpm = URPM->new;
     $urpm->parse_synthesis("synthesis.sample.cz");
     $urpm->traverse(sub {
 	# retrieve all packages from the dependency list
@@ -350,6 +353,9 @@ Force the re-reading of the RPM configuration files.
 $urpm->{depslist} is loaded when parsing sources (synthesis, hdlists or a plain
 rpm file).
 
+Synthesis and hdlists files are generated by L<genhdlist2> or L<gendistrib> (a
+gendhlist2 wrapper handling a whole media set) from L<rpmtools> package.
+
 =over
 
 =item $urpm->parse_synthesis($file [, callback => sub {...} ])
@@ -837,6 +843,11 @@ Options are:
     update => 0 / 1 : indicates whether this is an upgrade
     excludepath => [ ... ]
 
+=item $trans->addReinstall($pkg)
+
+Adds a package to be re-installed to the transaction represented by $trans.
+$pkg is an C<URPM::Package> object.
+
 =item $trans->remove($name)
 
 Adds a package to be erased to the transaction represented by $trans.
@@ -1044,6 +1055,8 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
+The L<URPM::Signature> implements the pubkey bits.
+
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
